# 要件定義作成プロンプト集
## ゴール
`{prompt}`
上記を満たす要件定義書を作成してください。

## プロジェクト - 宣言型 - 要件定義
### **プロジェクトの背景と目的**
### **範囲と制約事項**
### **機能要件と非機能要件**
### **ステークホルダーとその役割**
### **成功基準とプロジェクトの評価方法**
### **スケジュールとマイルストーン**
